@@ -426,7 +426,7 @@ class SkyDevice(SkySensorType):
         0: "_last_report",
         1: "_illuminance",
         2: "_uv",
-        3: "_rain_amount_previous_minute",
+        3: "_rain_accumulation_previous_minute",
         4: "_wind_lull",
         5: "_wind_average",
         6: "_wind_gust",
@@ -458,7 +458,7 @@ class TempestDevice(AirSensorType, SkySensorType):
         9: "_illuminance",
         10: "_uv",
         11: "_solar_radiation",
-        12: "_rain_amount_previous_minute",
+        12: "_rain_accumulation_previous_minute",
         13: "_precipitation_type",
         14: "_lightning_strike_average_distance",
         15: "_lightning_strike_count",
